#ifndef NT2_INCLUDE_FUNCTIONS_CAURND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CAURND_HPP_INCLUDED

#include <nt2/statistics/include/functions/caurnd.hpp>

#endif
